@@ -278,58 +278,73 @@ class SSHClient(object):
 
     @enter_and_leave_function
     def _scp_to_remote(self, local_path, remote_path):
-        """递归拷贝本地文件/文件夹到远端"""
+        """递归拷贝本地文件/文件夹到远端，确保父目录存在"""
         local_path = Path(local_path).resolve()
         remote_path = Path(remote_path)
 
-        # 1. 处理本地文件：直接上传
+        # 处理本地文件：确保远端父目录存在后再上传
         if local_path.is_file():
-            log.info(f" {self.__ip}:{self.__port} | Copy file: {local_path} -> {remote_path}")
-            self.__sftp.put(str(local_path), str(remote_path))
+            # 关键修复：创建文件的父目录（避免 "No such file" 错误）
+            remote_parent = remote_path.parent
+            mkdir_cmd = f"mkdir -p {remote_parent}"
+            rs = self.exec(mkdir_cmd)
+            if rs.exit_status_code != 0:
+                log.error(f" {self.__ip}:{self.__port} | 无法创建文件父目录 {remote_parent}，命令: {mkdir_cmd}")
+                return False
+
+            # 上传文件
+            log.info(f" {self.__ip}:{self.__port} | 拷贝文件: {local_path} -> {remote_path}")
+            try:
+                self.__sftp.put(str(local_path), str(remote_path))
+            except Exception as e:
+                log.error(f" {self.__ip}:{self.__port} | 文件上传失败: {local_path} -> {remote_path}, 错误: {str(e)}")
+                return False
+
             # 验证文件是否存在
             rs = self.exec(f"ls {remote_path}")
             if rs.exit_status_code != 0:
-                log.warning(f" {self.__ip}:{self.__port} | File copy failed: {remote_path} not found")
+                log.warning(f" {self.__ip}:{self.__port} | 文件拷贝失败: 远端未找到 {remote_path}")
                 return False
             return True
 
-        # 2. 处理本地文件夹：递归创建远端目录并拷贝所有内容
+        # 处理本地文件夹：递归创建目录并拷贝内容
         if local_path.is_dir():
-            # 创建远端目录（-p 确保父目录存在，忽略已存在错误）
+            # 创建远端根目录
             mkdir_cmd = f"mkdir -p {remote_path}"
             rs = self.exec(mkdir_cmd)
             if rs.exit_status_code != 0:
-                log.error(f" {self.__ip}:{self.__port} | Failed to create remote dir: {remote_path}, cmd: {mkdir_cmd}")
+                log.error(f" {self.__ip}:{self.__port} | 无法创建远端根目录 {remote_path}，命令: {mkdir_cmd}")
                 return False
 
-            # 遍历本地文件夹所有内容
+            # 遍历本地文件夹
             for root, dirs, files in os.walk(local_path):
-                # 计算远端对应目录路径
+                # 计算相对路径，保持目录结构
                 relative_root = Path(root).relative_to(local_path)
-                remote_root = remote_path / relative_root
+                remote_current_dir = remote_path / relative_root
 
-                # 创建远端子目录
-                if dirs:
-                    remote_dir_cmd = f"mkdir -p {remote_root}"
-                    self.exec(remote_dir_cmd)
-
-                # 拷贝文件
+                # 拷贝文件（关键：每个文件都确保其父目录存在）
                 for file in files:
                     local_file = Path(root) / file
-                    remote_file = remote_root / file
+                    remote_file = remote_current_dir / file
+
+                    # 强制创建当前文件的父目录（即使是子目录中的文件）
+                    remote_file_parent = remote_file.parent
+                    self.exec(f"mkdir -p {remote_file_parent}")
+
+                    # 上传文件
                     try:
                         self.__sftp.put(str(local_file), str(remote_file))
-                        log.debug(f" {self.__ip}:{self.__port} | Copied: {local_file} -> {remote_file}")
+                        log.debug(f" {self.__ip}:{self.__port} | 已拷贝: {local_file} -> {remote_file}")
                     except Exception as e:
                         log.error(
-                            f" {self.__ip}:{self.__port} | Copy failed: {local_file} -> {remote_file}, error: {str(e)}")
+                            f" {self.__ip}:{self.__port} | 拷贝失败: {local_file} -> {remote_file}, 错误: {str(e)}")
                         return False
 
-            log.info(f" {self.__ip}:{self.__port} | Directory copy completed: {local_path} -> {remote_path}")
+            log.info(f" {self.__ip}:{self.__port} | 文件夹拷贝完成: {local_path} -> {remote_path}")
             return True
 
-        # 3. 本地路径不存在或不是文件/文件夹
-        log.error(f" {self.__ip}:{self.__port} | Local path invalid: {local_path} (not file/dir)")
+        # 本地路径无效
+        log.error(f" {self.__ip}:{self.__port} | 本地路径无效: {local_path}（不是文件或文件夹）")
         return False
 
     @enter_and_leave_function
@@ -337,23 +352,25 @@ class SSHClient(object):
         try:
             if not self.__ssh:
                 if not self.reconnect():
-                    raise RuntimeError("ssh transport is not active and failed to reconnect.")
+                    raise RuntimeError("SSH连接未激活且重连失败")
             if not self.__sftp:
                 self.__sftp = self.__ssh.open_sftp()
 
-            # 转换为 Path 类型，统一路径处理（兼容字符串输入）
             local_path = Path(local_path)
             remote_path = Path(remote_path)
 
-            # 优化：如果本地是文件夹，远端路径自动指向目标文件夹（而非文件夹下的文件）
-            if local_path.is_dir() and self.exec(f"test -f {remote_path}").exit_status_code == 0:
-                log.warning(
-                    f" {self.__ip}:{self.__port} | Remote path exists as file: {remote_path}, will overwrite to dir")
-                self.exec(f"rm -f {remote_path}")
+            # 处理远端路径冲突（文件覆盖为目录）
+            if local_path.is_dir():
+                # 检查远端是否存在同名文件
+                if self.exec(f"test -f {remote_path}").exit_status_code == 0:
+                    log.warning(f" {self.__ip}:{self.__port} | 远端存在同名文件，删除后创建目录: {remote_path}")
+                    if self.exec(f"rm -f {remote_path}").exit_status_code != 0:
+                        log.error(f" {self.__ip}:{self.__port} | 无法删除远端冲突文件: {remote_path}")
+                        return False
 
             return self._scp_to_remote(local_path, remote_path)
-        except Exception:
-            log.warning(f" {self.__ip}:{self.__port} | SCP exception: local {local_path} -> remote {remote_path}",
+        except Exception as e:
+            log.warning(f" {self.__ip}:{self.__port} | SCP操作异常: 本地 {local_path} -> 远端 {remote_path}",
                         exc_info=True)
             return False
 
